This function loads a supported surface geometry from a file and returns a SurfaceGeometry object.
Details
This function supports loading surface geometries from the following file formats:
Freesurfer ASCII (.asc)
Freesurfer binary
GIFTI (.gii)
The appropriate loader is automatically selected based on the file extension or content.
Examples
# \donttest{
asc_path <- system.file("extdata", "std.8_lh.inflated.asc", package = "neurosurf")
lh_surface <- read_surf_geometry(asc_path)
#> loading /home/runner/work/_temp/Library/neurosurf/extdata/std.8_lh.inflated.asc
# }